@@ -2,7 +2,7 @@ setGeneric("getNobs",function(x)standardGeneric("getNobs"))
 setGeneric("seekData",function(x)standardGeneric("seekData"))
 setGeneric("readData",function(x,n)standardGeneric("readData"))
 setGeneric("readSlice",function(x,rows,cols)standardGeneric("readSlice"))
-setGeneric("readSubset",function(x,nrows,cols)standardGeneric("readSubset"))
+setGeneric("readChunk",function(x,nrows,cols)standardGeneric("readChunk"))
 setGeneric("codebookEntry",function(x) standardGeneric("codebookEntry"))
 # setGeneric("codebookStatsCateg",function(x,by=NULL) standardGeneric("codebookStatsCateg"))
 # setGeneric("codebookStatsMetric",function(x,by=NULL) standardGeneric("codebookStatsMetric"))
